# -*- coding: iso_8859_1 -*-

import astro
import numpy as np
import os, time

#-------------------------------------------------------------------------------------------
#	this scripts detects all new FITS files written to the specified folder
#	it computes their
#	- min, mean and max values
#	- median PSF fwhm (small, large) over the detected stars
#-------------------------------------------------------------------------------------------

#path information
path_to_watch = u"C:\\Documents and Settings\\Jrme\\Bureau\\03mar2011" 

#fit parameters
threshold = 0.01
psf_fit_area = 12

#-------------------------------------------------------------------------------------------

#loop to detect new fits files created in folder
before = dict ([(f, None) for f in os.listdir (path_to_watch)]) 
while 1: 
	time.sleep (10) 
	after = dict ([(f, None) for f in os.listdir (path_to_watch)]) 
	added = [f for f in after if not f in before] 
	#if added: print "Added: ", ", ".join (added) 	
	before = after 

	for f in added:
		if astro.check_extension(f):
			#loading new images
			image = astro.getdata(path_to_watch, [f])
			image = image[0,:,:]
			
			#calculating statistics
			mean = np.mean(image.flatten())
			maxi = np.max(image.flatten())
			mini = np.min(image.flatten())
			print  "                   min: ", mini, "     max: ", maxi, "     mean: ", mean

			#fitting stars
			stars = astro.find_stars(image, threshold)
			fwhm_1 = []
			fwhm_2 = []
			
			for xy in stars:
				#print xy
				p = astro.fit_gauss_elliptical([xy[0]-psf_fit_area,xy[1]-psf_fit_area],image[xy[0]-psf_fit_area:xy[0]+psf_fit_area+1, xy[1]-psf_fit_area:xy[1]+psf_fit_area+1])
				maxi, floor, height, mean_x, mean_y, fwhm_small, fwhm_large, angle = p
				
				fwhm_1.append(fwhm_small)
				fwhm_2.append(fwhm_large)
				
			print "                   FWHM small = %.2f" % np.ma.median(fwhm_1)
			print "                   FWHM large = %.2f" % np.ma.median(fwhm_2)
